/* Copyright (C) 2002 GFRN systems

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
   See the GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
   02111-1307, USA.

   The latest version of this program may be found at
   http://CQiNet.sourceforge.net

   This is the common header for all project files.
   
   $Log: common.h,v $
   Revision 1.3  2002/08/15 05:34:17  wb6ymh
   Added #define OUR_HOST for Windows build

   Revision 1.2  2002/08/12 17:10:47  wb6ymh
   Made TimeNow a global.
   Removed argument to GetTimeNow().

   Revision 1.1.1.1  2002/08/10 20:33:41  wb6ymh
   initial import

*/

#ifndef COMMON_H_
#define COMMON_H_

#ifndef _WIN32
   // FreeBSD, Linux, etc..
   #include <config.h>
   #define  READ(x,y,z) read(x,y,z)
   #define  WRITE(x,y,z) write(x,y,z)
   #define  CLOSE(x) close(x)
   #define  ERROR_CODE errno
   #define  ERROR_WOULD_BLOCK EAGAIN
   #define  ERROR_CONNECTED EISCONN
   #define  ERROR_IN_PROGRESS EINPROGRESS
   #define  SOCKET_ERROR   -1
   #define  SOCKET         int
   #define  INVALID_SOCKET -1
   #define  MODE_WRITE_BIN "w"
   #define  MODE_RDWR_BIN  "w+"
#else
   // Windoze
   #include <config.h.win32>
   // The following defines replace config.h for Windows
   #define HAVE_FTIME
   #define HAVE_STRICMP
   #define  READ(x,y,z) recv(x,y,z,0)
   #define  WRITE(x,y,z) send(x,y,z,0)
   #define  CLOSE(x) closesocket(x)
   #define  ERROR_CODE  WSAGetLastError()
   #define  ERROR_WOULD_BLOCK WSAEWOULDBLOCK
   #define  ERROR_CONNECTED WSAEISCONN
   #define  ERROR_IN_PROGRESS WSAEWOULDBLOCK
   #define  snprintf _snprintf
   #define  vsnprintf _vsnprintf
   #define  MODE_WRITE_BIN "wb"
   #define  MODE_RDWR_BIN  "w+b"
   #define  OUR_HOST "Windows"
#endif

#ifndef  FALSE
   #define FALSE  0
#endif

#ifndef  TRUE
   #define TRUE   !FALSE
#endif

#define DPRINTF(x)   if(DebugLevel) printf x
#define D2PRINTF(x)   if(DebugLevel > 1) printf x
#define D3PRINTF(x)   if(DebugLevel > 2) printf x

void LogNorm(char *fmt, ...);
void LogWarn(char *fmt, ...);
void LogErr(char *fmt, ...);
#define LOG_NORM(x)  LogNorm x
#define LOG_WARN(x)  LogWarn x
#define LOG_ERROR(x) LogErr x

// Local Error codes
#define  ERR_LOCAL_BASE          100000
#define  ERR_CONNECTION_CLOSED   ERR_LOCAL_BASE + 1
#define  ERR_CONFIG_FILE         ERR_LOCAL_BASE + 2
#define  ERR_CREATE_AVL          ERR_LOCAL_BASE + 3

extern int DebugLevel;  // 0 = no debug, 1 = debug, 2 = more debug ...

int ReadConfig();

#endif
